@@ -61,9 +61,10 @@ geom_xsidesegment <- function(mapping = NULL, data = NULL, stat = "identity", po
 #' @export
 GeomXsidesegment <- ggplot2::ggproto("GeomXsidesegment",
                                   ggplot2::GeomSegment,
-                                  default_aes = aes(colour = "black",
-                                                    xcolour = NA, size = 0.5,
-                                                    linetype = 1, alpha = NA),
+                                  default_aes = new_default_aes(
+                                    aes(xcolour = NA, xfill = NA),
+                                    ggplot2::GeomSegment$default_aes
+                                  ),
                                   setup_data = function(data, params){
                                     data <- parse_side_aes(data, params)
                                     ggplot2::GeomSegment$setup_data(data, params)
@@ -106,9 +107,10 @@ geom_ysidesegment <- function(mapping = NULL, data = NULL, stat = "identity", po
 #' @export
 GeomYsidesegment <- ggplot2::ggproto("GeomYsidesegment",
                                      ggplot2::GeomSegment,
-                                     default_aes = aes(colour = "black",
-                                                       ycolour = NA, size = 0.5,
-                                                       linetype = 1, alpha = NA),
+                                     default_aes = new_default_aes(
+                                       aes(ycolour = NA, yfill = NA),
+                                       ggplot2::GeomSegment$default_aes
+                                     ),
                                      setup_data = function(data, params){
                                        data <- parse_side_aes(data, params)
                                        ggplot2::GeomSegment$setup_data(data, params)
