@@ -379,12 +379,12 @@ FacetSideGrid <- ggplot2::ggproto("FacetSideGrid",
                                   init_scales = function(layout, x_scale = NULL, y_scale = NULL, params){
                                     scales <- FacetNull$init_scales(layout, x_scale, y_scale, params)
                                     if (!is.null(x_scale)&& !is.null(params$ggside$ysidex)){
-                                      side_indx <-  layout[layout$PANEL_TYPE=="y",]$SCALE_X
+                                      side_indx <-  unique(layout[layout$PANEL_TYPE=="y",]$SCALE_X)
                                       scales$x[side_indx] <- lapply(side_indx, function(i) params$ggside$ysidex$clone())
 
                                     }
                                     if (!is.null(y_scale)&& !is.null(params$ggside$xsidey)){
-                                      side_indx <-  layout[layout$PANEL_TYPE=="x",]$SCALE_Y
+                                      side_indx <-  unique(layout[layout$PANEL_TYPE=="x",]$SCALE_Y)
                                       scales$y[side_indx] <- lapply(side_indx, function(i) params$ggside$xsidey$clone())
 
                                     }
